import { GraphType, StatsModuleOptions } from "./types/types";
/**
 * Creates a StatsModule
 */
declare class StatsModule {
    private _name;
    private _graphType;
    private _dataType;
    /**
     * @param {string} name - The name of the module.
     * @param {StatsModuleOptions} options - The options for the module.
     * @param {GraphType} options.graphType - The graph type.
     * @param {"number" | "map"} options.dataType - The data type.
     */
    constructor(name: string, options: StatsModuleOptions);
    /**
     * Gets the name of the module.
     * @type {string}
     */
    get name(): string;
    /**
     * Gets the graph type of the module.
     * @type {GraphType}
     */
    get graphType(): GraphType;
    /**
     * Gets the data type of the module.
     * @type {"number" | "map"}
     */
    get dataType(): "number" | "map";
    /**
     * Validates the data provide to the module.
     * @param {any} data - The data to validate.
     * @returns {boolean}
     */
    validInputData(data: any): boolean;
}
export { StatsModule };
