/// <reference types="node" />
import { StatsManager } from "../StatsManager";
import { GraphType, GraphOptions } from "../types/types";
/** An abstract that should be extends to generate Graph  */
declare abstract class GraphBase {
    height: number;
    width: number;
    time: number;
    color: string;
    backgroundColor: string;
    statsmanager: StatsManager;
    graphType: GraphType;
    /**
     * @param {StatsManager} statsmanager
     * @param {GraphType} graphType - The GraphType
     * @param {GraphOptions} options - The options for the graph
     * @param {number} [options.height = 400] - The height of the graph
     * @param {number} [options.width = 800] - The width of the graph
     * @param {number} [options.time = 604800000] - The time in miliseconds that the graph will display default is 1 week
     * @param {string} [options.color = "rgba(227, 227, 227, 0.9)"] - The color of the text and borders
     * @param {string} [options.backgroundColor = "rgba(40, 40, 40, 0.9)"] - The color of the background
     * @param {number} [options.fontSize = 14] - The font size of the text
     */
    constructor(statsmanager: StatsManager, graphType: GraphType, options?: GraphOptions);
    /**
     * @param {string} targetStats - The name of the stats to display
     * @returns {Promise<Buffer>} - The graph buffer
     */
    generate(targetStats: string): Promise<Buffer>;
    /**
     * @abstract
     * @param {Array} data - GraphDatas
     * @returns {Promise<Buffer>} - The graph buffer
     */
    abstract generateCanvas(data: unknown[]): Promise<Buffer>;
}
export { GraphBase };
